﻿# Schalte Übernahme von Virtuellen Switchen beim Aufnehmen eines Hyper-V Hosts aus
Set-SCVMMServer -VMMServer localhost -AutomaticLogicalNetworkCreationEnabled $false -LogicalNetworkMatch "FirstDNSSuffixLabel" -BackupLogicalNetworkMatch "VirtualNetworkSwitchName"
   
#Variablen Abfragen
$Gruppennummer = [int] (Read-Host "Gruppennummer?")

#erzeuge Logisches Netzwerk Management und IP-Pool 
$logicalNetwork = New-SCLogicalNetwork -Name "Management" -LogicalNetworkDefinitionIsolation $false -EnableNetworkVirtualization $false -UseGRE $false -IsPVLAN $false
$allHostGroups = @()
$allHostGroups += Get-SCVMHostGroup -ID "0e3ba228-a059-46be-aa41-2f5cf0f4b96e"
$allSubnetVlan = @()
$allSubnetVlan += New-SCSubnetVLan -Subnet "172.16.0.0/16" -VLanID 0
New-SCLogicalNetworkDefinition -Name "Management_0" -LogicalNetwork $logicalNetwork -VMHostGroup $allHostGroups -SubnetVLan $allSubnetVlan -RunAsynchronously
New-SCVMNetwork -Name "Management" -IsolationType "NoIsolation" -LogicalNetwork $logicalNetwork
#IP-Pool
$logicalNetwork = Get-SCLogicalNetwork -Name "Management"
$logicalNetworkDefinition = Get-SCLogicalNetworkDefinition -LogicalNetwork $logicalNetwork -Name "Management_0"
# Gateways
$allGateways = @()
$allGateways += New-SCDefaultGateway -IPAddress "172.16.0.1" -Automatic
# DNS servers 
$allDnsServer = @("172.16.0.2")
# DNS suffixes
$allDnsSuffixes = @("itcamp.de")
# WINS servers
$allWinsServers = @()
New-SCStaticIPAddressPool -Name "Management_IP-Pool" -LogicalNetworkDefinition $logicalNetworkDefinition -Subnet "172.16.0.0/16" -IPAddressRangeStart "172.16.$GruppenNummer.20" -IPAddressRangeEnd "172.16.$GruppenNummer.254" -DefaultGateway $allGateways -DNSServer $allDnsServer -DNSSuffix "" -DNSSearchSuffix $allDnsSuffixes -RunAsynchronously

#erzeuge Logisches Netzwerk SMB1 und IP-Pool 
$logicalNetwork = New-SCLogicalNetwork -Name "SMB1" -LogicalNetworkDefinitionIsolation $false -EnableNetworkVirtualization $false -UseGRE $false -IsPVLAN $false
$allHostGroups = @()
$allHostGroups += Get-SCVMHostGroup -ID "0e3ba228-a059-46be-aa41-2f5cf0f4b96e"
$allSubnetVlan = @()
$allSubnetVlan += New-SCSubnetVLan -Subnet "172.17.0.0/16" -VLanID 0
New-SCLogicalNetworkDefinition -Name "SMB1_0" -LogicalNetwork $logicalNetwork -VMHostGroup $allHostGroups -SubnetVLan $allSubnetVlan -RunAsynchronously
New-SCVMNetwork -Name "SMB1" -IsolationType "NoIsolation" -LogicalNetwork $logicalNetwork
#IP-Pool
$logicalNetwork = Get-SCLogicalNetwork -Name "SMB1"
$logicalNetworkDefinition = Get-SCLogicalNetworkDefinition -LogicalNetwork $logicalNetwork -Name "SMB1_0"
# Gateways
$allGateways = @()
# DNS servers 
$allDnsServer = @()
# DNS suffixes
$allDnsSuffixes = @()
# WINS servers
$allWinsServers = @()
New-SCStaticIPAddressPool -Name "SMB1_IP-Pool" -LogicalNetworkDefinition $logicalNetworkDefinition -Subnet "172.17.0.0/16" -IPAddressRangeStart "172.17.$GruppenNummer.20" -IPAddressRangeEnd "172.17.$GruppenNummer.254" -DefaultGateway $allGateways -DNSServer $allDnsServer -DNSSuffix "" -DNSSearchSuffix $allDnsSuffixes -RunAsynchronously

#erzeuge Logisches Netzwerk SMB1 und IP-Pool 
$logicalNetwork = New-SCLogicalNetwork -Name "SMB2" -LogicalNetworkDefinitionIsolation $false -EnableNetworkVirtualization $false -UseGRE $false -IsPVLAN $false
$allHostGroups = @()
$allHostGroups += Get-SCVMHostGroup -ID "0e3ba228-a059-46be-aa41-2f5cf0f4b96e"
$allSubnetVlan = @()
$allSubnetVlan += New-SCSubnetVLan -Subnet "172.18.0.0/16" -VLanID 0
New-SCLogicalNetworkDefinition -Name "SMB2_0" -LogicalNetwork $logicalNetwork -VMHostGroup $allHostGroups -SubnetVLan $allSubnetVlan -RunAsynchronously
New-SCVMNetwork -Name "SMB2" -IsolationType "NoIsolation" -LogicalNetwork $logicalNetwork
#IP-Pool
$logicalNetwork = Get-SCLogicalNetwork -Name "SMB2"
$logicalNetworkDefinition = Get-SCLogicalNetworkDefinition -LogicalNetwork $logicalNetwork -Name "SMB2_0"
# Gateways
$allGateways = @()
# DNS servers 
$allDnsServer = @()
# DNS suffixes
$allDnsSuffixes = @()
# WINS servers
$allWinsServers = @()
New-SCStaticIPAddressPool -Name "SMB2_IP-Pool" -LogicalNetworkDefinition $logicalNetworkDefinition -Subnet "172.18.0.0/16" -IPAddressRangeStart "172.18.$GruppenNummer.20" -IPAddressRangeEnd "172.18.$GruppenNummer.254" -DefaultGateway $allGateways -DNSServer $allDnsServer -DNSSuffix "" -DNSSearchSuffix $allDnsSuffixes -RunAsynchronously

#Create Hyper-V Port Profile - SMB
New-SCVirtualNetworkAdapterNativePortProfile -Name "SMB" -Description "" -AllowIeeePriorityTagging $false -AllowMacAddressSpoofing $false -AllowTeaming $false -EnableDhcpGuard $false -EnableGuestIPNetworkVirtualizationUpdates $false -EnableIov $false -EnableIPsecOffload $false -EnableRouterGuard $false -EnableVmq $true -MinimumBandwidthWeight "10" -RunAsynchronously

#Create Hyper-V Uplink Port Profile - 1GBitTeam
$definition = @()
$definition += Get-SCLogicalNetworkDefinition -Name "Management_0" 
$definition += Get-SCLogicalNetworkDefinition -Name "SMB1_0" 
$definition += Get-SCLogicalNetworkDefinition -Name "SMB2_0" 
New-SCNativeUplinkPortProfile -Name "GBit1Team" -Description "" -LogicalNetworkDefinition $definition -EnableNetworkVirtualization $false -LBFOLoadBalancingAlgorithm "Dynamic" -LBFOTeamMode "SwitchIndependent" -RunAsynchronously

#Create Port Classification for SMB workloads
New-SCPortClassification -Name "SMB workload" -Description "Port classification for host SMB workloads."

#Create Logical Switch - ITCampSwitch
$virtualSwitchExtensions = @()
$virtualSwitchExtensions += Get-SCVirtualSwitchExtension -ID "c50ee12b-cc55-449e-9385-2ded3afb2b36" -Name "Microsoft Windows Filtering Platform"
$logicalSwitch = New-SCLogicalSwitch -Name "ITCampSwitch" -Description "" -EnableSriov $false -SwitchUplinkMode "Team" -VirtualSwitchExtensions $virtualSwitchExtensions
$nativeProfile = Get-SCNativeUplinkPortProfile -Name "GBit1Team"
New-SCUplinkPortProfileSet -Name "GBit1Team_184018c9-c65c-4e8a-9f07-4ab1279bef5a" -LogicalSwitch $logicalSwitch -RunAsynchronously -NativeUplinkPortProfile $nativeProfile
$portClassification = Get-SCPortClassification -Name "Host management" 
$nativeProfile = Get-SCVirtualNetworkAdapterNativePortProfile -Name "Host management" 
New-SCVirtualNetworkAdapterPortProfileSet -Name "Host management" -PortClassification $portClassification -LogicalSwitch $logicalSwitch -RunAsynchronously -VirtualNetworkAdapterNativePortProfile $nativeProfile
$portClassification = Get-SCPortClassification -Name "Medium bandwidth"
$nativeProfile = Get-SCVirtualNetworkAdapterNativePortProfile -Name "Medium Bandwidth Adapter"
New-SCVirtualNetworkAdapterPortProfileSet -Name "Medium bandwidth" -PortClassification $portClassification -LogicalSwitch $logicalSwitch -RunAsynchronously -VirtualNetworkAdapterNativePortProfile $nativeProfile
$portClassification = Get-SCPortClassification -Name "Low bandwidth"
$nativeProfile = Get-SCVirtualNetworkAdapterNativePortProfile -Name "Low Bandwidth Adapter"
New-SCVirtualNetworkAdapterPortProfileSet -Name "Low bandwidth" -PortClassification $portClassification -LogicalSwitch $logicalSwitch -RunAsynchronously -VirtualNetworkAdapterNativePortProfile $nativeProfile
$portClassification = Get-SCPortClassification -Name "High bandwidth"
$nativeProfile = Get-SCVirtualNetworkAdapterNativePortProfile -Name "High Bandwidth Adapter"
New-SCVirtualNetworkAdapterPortProfileSet -Name "High bandwidth" -PortClassification $portClassification -LogicalSwitch $logicalSwitch -RunAsynchronously -VirtualNetworkAdapterNativePortProfile $nativeProfile
$portClassification = Get-SCPortClassification -Name "SMB workload"
$nativeProfile = Get-SCVirtualNetworkAdapterNativePortProfile -Name "SMB"
New-SCVirtualNetworkAdapterPortProfileSet -Name "SMB workload" -PortClassification $portClassification -LogicalSwitch $logicalSwitch -RunAsynchronously -VirtualNetworkAdapterNativePortProfile $nativeProfile
