﻿# Deployen einer VM aus dieser Vorlage (ohne Netzwerk) - Version 1
#########################################
$GruppenNummer = "{0:D2}" -f [int](Read-Host "Gruppen Nummer?")
$hostGruppe = "Gruppe$GruppenNummer"
$vmName = Read-Host -Prompt "Wie soll die VM heissen?"
$templateName = "Vorlage Windows Server 2012 R2 Eval"
$myJobGroupID = [System.Guid]::NewGuid()
$template = Get-SCVMTemplate -VMMServer localhost -Name "$templateName" | select -First 1

if ($Template.Count -gt 0)
{
    $diskSpaceGB = ((($template.VirtualHardDisks | Measure-Object -Sum -Property Size).Sum / 1GB) + 0.5 )
    $topRatedHost = Get-SCVMHostRating -VMMServer localhost -VMTemplate $template -VMHostGroup (Get-SCVMHostGroup -VMMServer localhost -name $hostGruppe) -VMName $vmName -DiskSpaceGB $diskSpaceGB | where Rating -gt 0 | Sort-Object -Descending -Property Rating | select -First 1
    if ($topRatedHost.Count -gt 0)
    {
        $virtualMachineConfiguration = New-SCVMConfiguration -VMTemplate $template -Name "$vmName" -JobVariable $myJobGroupID
        Write-Output $virtualMachineConfiguration
        $vmHost = Get-SCVMHost -VMMServer localhost -ComputerName $topRatedHost.Name
        Set-SCVMConfiguration -VMConfiguration $virtualMachineConfiguration -VMHost $vmHost
        Update-SCVMConfiguration -VMConfiguration $virtualMachineConfiguration
        Get-SCVirtualNetworkAdapterConfiguration -VMConfiguration $virtualMachineConfiguration -VMMServer localhost -Verbose
        Update-SCVMConfiguration -VMConfiguration $virtualMachineConfiguration -ValidateOnly $false -VMName "$vmName"
        Write-Host "Deploying $vmName on $topRatedHost"
        New-SCVirtualMachine -VMConfiguration $virtualMachineConfiguration -Name $vmName -ComputerName $vmName -StartVM -StartAction "NeverAutoTurnOnVM" -StopAction "ShutdownGuestOS"  -JobGroup $myJobGroupID -RunAsynchronously
    }
    else
    {
        write "placement of vm failed - host ratings did not return any server"
    }
}