﻿#IT Camp Hyper-V Hosts (Notebook) Netzwerk GBit Karte converged Config erzeugen
[CmdletBinding()]
param (
    [Parameter(Mandatory=$false)] [boolean] $reset = $false
)

# Set CorfirmPreference to noask
$ConfirmPreference="None"

#Extrahiere aus Computernamen Gruppe und IP
$Group = [int]$env:computername.substring(7,2)
$Number = [int]$env:computername.Substring(10,3)
$IPManagement = "172.16.$Group.$Number"
$IPSMB1 = "172.17.$Group.$Number"
$IPSMB2 = "172.18.$Group.$Number"

#
#Set Policy to unrestricted - this script is not signed :-(
#Set-ExecutionPolicy Unrestricted
#
if($reset -eq $false) {
    Write-Verbose "Setting the Networks with $IP"

    #bfrank - set Hyper-V V-Switch MAC Address range according to group number - to eliminate empty values causing duplicate MACs when cloning a Hyper-V system.
    $macAddressMinimum = "00155D{0:X2}{1:X2}01" -f $Group,$number
    $macAddressMaximum = "00155D{0:X2}{1:X2}FF" -f $Group,$number
    Set-VMHost -MacAddressMinimum $macAddressMinimum -MacAddressMaximum $macAddressMaximum


    # Create the NIC team using all the NICs in the host, setting -TeamingMode (Lacp, Static, SwitchIndependent)
    # and -LoadBalancingAlgorithm (Dynamic, HyperVPort, IPAdresses, MacAddresses, TransportPort)
    New-NetLBFOTeam -Name "1GBitTeam" -TeamNICName "1GBitTeam" -TeamMembers Ethernet* -TeamingMode SwitchIndependent -LoadBalancingAlgorithm Dynamic -Confirm:$false 

    # Create the Hyper-V virtual switch and management virtual network adapter
    New-VMSwitch "ITCampSwitch" -MinimumBandwidthMode weight -NetAdapterName "1GBitTeam" -AllowManagementOS 0 -Confirm:$false

    # Create additional virtual network adapters and assign VConvergedSwitch IDs
    Add-VMNetworkAdapter -ManagementOS -Name "Management" -SwitchName "ITCampSwitch"
    Add-VMNetworkAdapter -ManagementOS -Name "SMB1" -SwitchName "ITCampSwitch"
    Add-VMNetworkAdapter -ManagementOS -Name "SMB2" -SwitchName "ITCampSwitch"

#    Set-VMNetworkAdapterVlan -ManagementOS -VMNetworkAdapterName "Management" -Access –VlanId 16
#    Set-VMNetworkAdapterVlan -ManagementOS -VMNetworkAdapterName "SMB1" -Access -VlanId 17
#    Set-VMNetworkAdapterVlan -ManagementOS -VMNetworkAdapterName "SMB2" -Access -VlanId 18


    # Assign static IP addresses to the virtual network adapters   
    Set-NetIPInterface -InterfaceAlias "vEthernet (Management)" -dhcp Disabled -verbose
    New-NetIPAddress -AddressFamily IPv4 -PrefixLength 16 -InterfaceAlias "vEthernet (Management)" -IPAddress $IPManagement -DefaultGateway 172.16.0.1 -verbose
    Set-DnsClientServerAddress -InterfaceAlias "vEthernet (Management)" -ServerAddresses 172.16.0.2
    
    Set-NetIPInterface -InterfaceAlias "vEthernet (SMB1)" -dhcp Disabled -verbose
    New-NetIPAddress -AddressFamily IPv4 -PrefixLength 16 -InterfaceAlias "vEthernet (SMB1)" -IPAddress $IPSMB1 -verbose
    Set-NetAdapterBinding -Name "vEthernet (SMB1)" -ComponentID ms_tcpip6 -Enabled $False
    
    Set-NetIPInterface -InterfaceAlias "vEthernet (SMB2)" -dhcp Disabled -verbose
    New-NetIPAddress -AddressFamily IPv4 -PrefixLength 16 -InterfaceAlias "vEthernet (SMB2)" -IPAddress $IPSMB2 -verbose
    Set-NetAdapterBinding -Name "vEthernet (SMB2)" -ComponentID ms_tcpip6 -Enabled $False
    

    # Set the QoS bucket
    Set-VMSwitch "ITCampSwitch" -DefaultFlowMinimumBandwidthWeight 1
    # Configure traffic performance isolation by using QoS
    Set-VMNetworkAdapter -ManagementOS -Name "Management" -MinimumBandwidthWeight 20 -verbose
    Set-VMNetworkAdapter -ManagementOS -Name "SMB1" -MinimumBandwidthWeight 10 -verbose
    Set-VMNetworkAdapter -ManagementOS -Name "SMB2" -MinimumBandwidthWeight 10 -verbose

    # Configure SMBMultichannelConstraint for SOFS
    New-SmbMultichannelConstraint -ServerName SOFS -InterfaceAlias "vEthernet (SMB1)","vEthernet (SMB2)" -Confirm:$false

    # Show VLanIDs on VMNetWorkAdapters
    Get-VMNetworkAdapterVlan -ManagementOS -VMNetworkAdapterName *

} else {


    # Remove IP Settings
    Set-NetIPInterface -InterfaceAlias "vEthernet (Management)" -dhcp Enable -verbose
    Set-NetIPInterface -InterfaceAlias "vEthernet (SMB1)" -dhcp Enable -verbose
    Set-NetIPInterface -InterfaceAlias "vEthernet (SMB2)" -dhcp Enable -verbose
    
    # Remove additional virtual network adapters and assign VLAN IDs
    Remove-VMNetworkAdapter -ManagementOS -Name "Management" -SwitchName "ITCampSwitch"
    Remove-VMNetworkAdapter -ManagementOS -Name "SMB1" -SwitchName "ITCampSwitch"
    Remove-VMNetworkAdapter -ManagementOS -Name "SMB2" -SwitchName "ITCampSwitch"

    # delete Hyper-V virtual switch
    Remove-VMSwitch -Name "ITCampSwitch" -Force -Confirm:$false

    # Delete LBFOTeam 
    Remove-NetLbfoTeam -Name "1GBitTeam" -Confirm:$false
}